Changelog
=========

All notable changes to ``kalendar`` will be documented in this file.

The format is based on `Keep a
Changelog <https://keepachangelog.com/en/1.0.0/>`__, and this project
adheres to `Semantic
Versioning <https://semver.org/spec/v2.0.0.html>`__.

Unreleased
----------

Added
~~~~~

-  Dekad module
-  Package setup structure
-  Unit tests
-  Pre-commit hooks: black, flake8, mypy plus others
-  Sphinx documentation
